aboutsummaryrefslogtreecommitdiff
path: root/backends/platform/symbian
diff options
context:
space:
mode:
Diffstat (limited to 'backends/platform/symbian')
-rw-r--r--backends/platform/symbian/BuildPackageUpload_LocalSettings.pl139
-rw-r--r--backends/platform/symbian/S60v3/BLD.INF.in2
-rw-r--r--backends/platform/symbian/S60v3/icons.mk34
-rw-r--r--backends/platform/symbian/S60v3/scummvm-CVS-SymbianS60v3.pkg11
-rw-r--r--backends/platform/symbian/UIQ3/scummvm-CVS-SymbianUIQ3.pkg10
-rw-r--r--backends/platform/symbian/res/scummvm.svg8
-rw-r--r--backends/platform/symbian/src/ScummApp.cpp10
-rw-r--r--backends/platform/symbian/src/ScummApp.h10
-rw-r--r--backends/platform/symbian/src/ScummVMApp.cpp10
-rw-r--r--backends/platform/symbian/src/ScummVMApp.h10
-rw-r--r--backends/platform/symbian/src/SymbianActions.cpp7
-rw-r--r--backends/platform/symbian/src/SymbianActions.h7
-rw-r--r--backends/platform/symbian/src/SymbianOS.cpp10
-rw-r--r--backends/platform/symbian/src/SymbianOS.h10
-rw-r--r--backends/platform/symbian/src/portdefs.h10
15 files changed, 164 insertions, 124 deletions
diff --git a/backends/platform/symbian/S60v3/BLD.INF.in b/backends/platform/symbian/S60v3/BLD.INF.in
index f7b7090adf..d499fccc39 100644
--- a/backends/platform/symbian/S60v3/BLD.INF.in
+++ b/backends/platform/symbian/S60v3/BLD.INF.in
@@ -7,5 +7,5 @@ PRJ_MMPFILES
// empty base file, will be updated by Perl build scripts
//STOP_AUTO_PROJECTS//
-
+gnumakefile icons.mk
.\ScummVM_S60v3.mmp
diff --git a/backends/platform/symbian/S60v3/icons.mk b/backends/platform/symbian/S60v3/icons.mk
new file mode 100644
index 0000000000..5f17dd7b8b
--- /dev/null
+++ b/backends/platform/symbian/S60v3/icons.mk
@@ -0,0 +1,34 @@
+ifeq (WINS,$(findstring WINS, $(PLATFORM)))
+ZDIR=$(EPOCROOT)epoc32\release\$(PLATFORM)\$(CFG)\Z
+else
+ZDIR=$(EPOCROOT)epoc32\data\z
+endif
+
+TARGETDIR=$(ZDIR)\RESOURCE\APPS
+ICONTARGETFILENAME=$(TARGETDIR)\scummvm.mif
+
+do_nothing :
+ @rem do_nothing
+
+MAKMAKE : do_nothing
+
+BLD : do_nothing
+
+CLEAN : do_nothing
+
+LIB : do_nothing
+
+CLEANLIB : do_nothing
+
+RESOURCE :
+ mifconv $(ICONTARGETFILENAME) \
+ /c32 ..\res\scummvm.svg
+
+FREEZE : do_nothing
+
+SAVESPACE : do_nothing
+
+RELEASABLES :
+ @echo $(ICONTARGETFILENAME)
+
+FINAL : do_nothing \ No newline at end of file
diff --git a/backends/platform/symbian/S60v3/scummvm-CVS-SymbianS60v3.pkg b/backends/platform/symbian/S60v3/scummvm-CVS-SymbianS60v3.pkg
index ec57e4346f..73cbad17cd 100644
--- a/backends/platform/symbian/S60v3/scummvm-CVS-SymbianS60v3.pkg
+++ b/backends/platform/symbian/S60v3/scummvm-CVS-SymbianS60v3.pkg
@@ -41,11 +41,12 @@
*"..\res\scummvm.key","..\res\scummvm.cer",KEY="scummvm"
; Launcher, Application, AIF & Resource file
-"\s60v3\epoc32\release\gcce\urel\ScummVM.exe"- "!:\sys\bin\ScummVM.exe"
-"\s60v3\epoc32\data\z\resource\apps\ScummVM.rsc"- "!:\resource\apps\ScummVM.rsc"
-"\s60v3\epoc32\Data\Z\resource\apps\scummvm_loc.rsc"- "!:\resource\apps\scummvm_loc.rsc"
-"\s60v3\epoc32\data\Z\resource\APPS\scummvm.MBM"- "!:\resource\apps\scummvm.MBM"
-"\s60v3\epoc32\data\z\private\10003a3f\apps\scummvm_reg.rsc"-"!:\private\10003a3f\import\apps\scummvm_reg.rsc"
+"\epoc32\release\gcce\urel\ScummVM.exe"- "!:\sys\bin\ScummVM.exe"
+"\epoc32\data\z\resource\apps\ScummVM.rsc"- "!:\resource\apps\ScummVM.rsc"
+"\epoc32\Data\Z\resource\apps\scummvm_loc.rsc"- "!:\resource\apps\scummvm_loc.rsc"
+"\epoc32\data\Z\resource\APPS\scummvm.MBM"- "!:\resource\apps\scummvm.MBM"
+"\epoc32\data\Z\resource\APPS\scummvm.MIF"- "!:\resource\apps\scummvm.MIF"
+"\epoc32\data\z\private\10003a3f\apps\scummvm_reg.rsc"-"!:\private\10003a3f\import\apps\scummvm_reg.rsc"
; Config/log files: 'empty' will automagically be removed on uninstall
""-"c:\data\scummvm\scummvm.ini",FILENULL
diff --git a/backends/platform/symbian/UIQ3/scummvm-CVS-SymbianUIQ3.pkg b/backends/platform/symbian/UIQ3/scummvm-CVS-SymbianUIQ3.pkg
index 7ee2c57844..1e529127f9 100644
--- a/backends/platform/symbian/UIQ3/scummvm-CVS-SymbianUIQ3.pkg
+++ b/backends/platform/symbian/UIQ3/scummvm-CVS-SymbianUIQ3.pkg
@@ -41,11 +41,11 @@
*"..\res\scummvm.key","..\res\scummvm.cer",KEY="scummvm"
; Application, AIF & Resource file
-"\uiq3\epoc32\release\gcce\urel\ScummVM.exe"- "!:\sys\bin\ScummVM.exe"
-"\uiq3\epoc32\data\z\resource\apps\ScummVM.rsc"- "!:\resource\apps\ScummVM.rsc"
-"\uiq3\epoc32\Data\Z\resource\apps\scummvm_loc.rsc"- "!:\resource\apps\scummvm_loc.rsc"
-"\uiq3\epoc32\data\Z\resource\APPS\scummvm.MBM"- "!:\resource\apps\scummvm.MBM"
-"\uiq3\epoc32\data\z\private\10003a3f\apps\scummvm_reg.rsc"-"!:\private\10003a3f\import\apps\scummvm_reg.rsc"
+"\epoc32\release\gcce\urel\ScummVM.exe"- "!:\sys\bin\ScummVM.exe"
+"\epoc32\data\z\resource\apps\ScummVM.rsc"- "!:\resource\apps\ScummVM.rsc"
+"\epoc32\Data\Z\resource\apps\scummvm_loc.rsc"- "!:\resource\apps\scummvm_loc.rsc"
+"\epoc32\data\Z\resource\APPS\scummvm.MBM"- "!:\resource\apps\scummvm.MBM"
+"\epoc32\data\z\private\10003a3f\apps\scummvm_reg.rsc"-"!:\private\10003a3f\import\apps\scummvm_reg.rsc"
; Config/log files: 'empty' will automagically be removed on uninstall
""-"c:\shared\scummvm\scummvm.ini",FILENULL
diff --git a/backends/platform/symbian/res/scummvm.svg b/backends/platform/symbian/res/scummvm.svg
new file mode 100644
index 0000000000..850c03214b
--- /dev/null
+++ b/backends/platform/symbian/res/scummvm.svg
@@ -0,0 +1,8 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 1.1 Tiny//EN" "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11-tiny.dtd">
+<svg baseProfile="tiny" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.0" width="64" height="64" viewBox="9 26.110352 256 256">
+<metadata/>
+<defs/>
+<path d="M 249.05009,175.79971 C 248.53891,172.49798 247.74049,169.19936 246.65481,166.01745 C 244.6791,160.23291 241.91403,154.65205 238.4964,149.46763 C 236.32392,146.17631 234.09037,142.91366 231.68153,139.75934 C 229.45137,136.83425 227.17371,134.22747 224.56695,131.62588 C 223.74026,130.79914 222.40012,129.84113 222.07216,128.70756 C 221.69556,127.40207 222.75297,126.29976 223.40211,125.23964 C 224.20619,123.92114 224.94806,122.57502 225.79738,121.27787 C 227.24043,119.07377 228.67556,116.86445 230.06658,114.63325 C 234.87183,106.93946 239.32763,99.044058 243.4645,91.030924 C 245.92763,86.263259 248.09332,81.587795 247.50978,76.169476 C 247.25306,73.778352 246.07239,71.52788 244.62482,69.569657 C 239.25751,62.317618 231.87717,55.638095 224.07953,50.624545 C 218.42271,46.987846 212.35761,43.903345 206.11838,41.196529 C 193.73941,35.828738 180.59028,31.834152 167.22403,29.164322 C 160.40576,27.802058 153.42464,26.712246 146.4322,26.546587 C 124.6627,26.031896 100.03934,28.496474 80.296996,37.311862 C 73.836092,40.195278 67.506939,43.813744 61.941153,47.98545 C 51.870942,55.534948 43.25565,65.529749 36.935544,75.952759 C 34.371765,80.183853 32.219073,84.872333 30.804867,89.539465 C 28.571315,96.918087 28.082761,104.53791 28.284629,112.16294 C 28.313467,113.28975 28.366619,114.41394 28.443521,115.53657 C 28.909457,122.48698 30.263726,129.38843 32.524986,136.03305 C 33.648547,139.34312 34.99716,142.58598 36.563474,145.73873 C 39.861216,152.38022 44.280257,158.23665 48.557933,164.34731 C 49.959699,166.34981 49.175411,166.96765 48.021315,168.83262 C 47.228546,170.11206 46.438038,171.39254 45.638482,172.66572 C 44.037111,175.21625 42.426125,177.75949 40.837758,180.31837 C 37.87816,185.07978 35.20129,189.98288 32.264875,194.75472 C 28.544739,200.79244 24.471757,206.79161 22.644767,213.59303 C 21.740603,216.96562 21.542693,220.49448 22.381265,223.92124 C 24.132483,231.06961 28.956956,237.15526 34.331618,242.40949 C 37.329667,245.34448 41.158373,247.51785 44.664767,249.88918 C 59.186816,259.70061 77.54492,265.42784 94.769847,269.75584 C 112.22775,274.14322 130.71308,275.66021 148.78336,274.60893 C 184.31325,272.54496 222.35715,260.35596 239.61714,229.8902 C 242.86285,224.15671 245.42664,217.75745 247.18859,211.50406 C 250.41735,200.01936 250.85728,187.52508 249.05009,175.79971 z "/>
+<image y="45.56538" x="49.37302" height="208.96297" width="173.89946" xlink:href="E:\scummvm_green.gif" style="fill:#000000;fill-opacity:1;stroke:#000000;stroke-opacity:1"/>
+</svg>
diff --git a/backends/platform/symbian/src/ScummApp.cpp b/backends/platform/symbian/src/ScummApp.cpp
index 9341b374f9..3c3c0dc065 100644
--- a/backends/platform/symbian/src/ScummApp.cpp
+++ b/backends/platform/symbian/src/ScummApp.cpp
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/ScummApp.h b/backends/platform/symbian/src/ScummApp.h
index bd81edaa83..bf0eb6f436 100644
--- a/backends/platform/symbian/src/ScummApp.h
+++ b/backends/platform/symbian/src/ScummApp.h
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/ScummVMApp.cpp b/backends/platform/symbian/src/ScummVMApp.cpp
index e30cb62e87..daa0e75744 100644
--- a/backends/platform/symbian/src/ScummVMApp.cpp
+++ b/backends/platform/symbian/src/ScummVMApp.cpp
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/ScummVMApp.h b/backends/platform/symbian/src/ScummVMApp.h
index 0c422ad178..9f1b6f8452 100644
--- a/backends/platform/symbian/src/ScummVMApp.h
+++ b/backends/platform/symbian/src/ScummVMApp.h
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/SymbianActions.cpp b/backends/platform/symbian/src/SymbianActions.cpp
index 25dd1472c8..cb2652eac4 100644
--- a/backends/platform/symbian/src/SymbianActions.cpp
+++ b/backends/platform/symbian/src/SymbianActions.cpp
@@ -1,5 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2001-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/SymbianActions.h b/backends/platform/symbian/src/SymbianActions.h
index c1176d00b0..0facde763c 100644
--- a/backends/platform/symbian/src/SymbianActions.h
+++ b/backends/platform/symbian/src/SymbianActions.h
@@ -1,5 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2001-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/SymbianOS.cpp b/backends/platform/symbian/src/SymbianOS.cpp
index 846f1cce06..737795182e 100644
--- a/backends/platform/symbian/src/SymbianOS.cpp
+++ b/backends/platform/symbian/src/SymbianOS.cpp
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/SymbianOS.h b/backends/platform/symbian/src/SymbianOS.h
index 80278af58c..c7142b621d 100644
--- a/backends/platform/symbian/src/SymbianOS.h
+++ b/backends/platform/symbian/src/SymbianOS.h
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/src/portdefs.h b/backends/platform/symbian/src/portdefs.h
index 906b6317d3..4299eb59ad 100644
--- a/backends/platform/symbian/src/portdefs.h
+++ b/backends/platform/symbian/src/portdefs.h
@@ -1,8 +1,8 @@
-/* ScummVM - Scumm Interpreter
- * Copyright (C) 2003-2005 Andreas 'Sprawl' Karlsson - Original EPOC port, ESDL
- * Copyright (C) 2003-2005 Lars 'AnotherGuest' Persson - Original EPOC port, Audio System
- * Copyright (C) 2005 Jurgen 'SumthinWicked' Braam - EPOC/CVS maintainer
- * Copyright (C) 2005-2006 The ScummVM project
+/* ScummVM - Graphic Adventure Engine
+ *
+ * ScummVM is the legal property of its developers, whose names
+ * are too numerous to list here. Please refer to the COPYRIGHT
+ * file distributed with this source distribution.
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
diff --git a/backends/platform/symbian/BuildPackageUpload_LocalSettings.pl b/backends/platform/symbian/BuildPackageUpload_LocalSettings.pl
index bd2a3cf0dc..30d5bd25d8 100644
--- a/backends/platform/symbian/BuildPackageUpload_LocalSettings.pl
+++ b/backends/platform/symbian/BuildPackageUpload_LocalSettings.pl
@@ -12,6 +12,7 @@
MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
MACRO DISABLE_PARALLACTION // LIB:scummvm_parallaction.lib
+ MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
";
##
@@ -141,8 +142,8 @@ if (1) # all regular combo's
MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
$SDK_Variations{'ALL'}{'agos'} = "$DefaultTopMacros
@@ -150,41 +151,41 @@ if (1) # all regular combo's
//MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
MACRO DISABLE_SKY // LIB:scummvm_sky.lib
MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
- MACRO DISABLE_GOB // LIB:scummvm_gob.lib
+ MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
$SDK_Variations{'ALL'}{'sky'} = "$DefaultTopMacros
MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
- //MACRO DISABLE_SKY // LIB:scummvm_sky.lib
+ //MACRO DISABLE_SKY // LIB:scummvm_sky.lib
MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
- MACRO DISABLE_GOB // LIB:scummvm_gob.lib
+ MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
$SDK_Variations{'ALL'}{'queen'} = "$DefaultTopMacros
MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
- MACRO DISABLE_SKY // LIB:scummvm_sky.lib
+ MACRO DISABLE_SKY // LIB:scummvm_sky.lib
//MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
- MACRO DISABLE_GOB // LIB:scummvm_gob.lib
+ MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
$SDK_Variations{'ALL'}{'gob'} = "$DefaultTopMacros
@@ -196,9 +197,9 @@ if (1) # all regular combo's
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
$SDK_Variations{'ALL'}{'saga'} = "$DefaultTopMacros
@@ -212,7 +213,7 @@ if (1) # all regular combo's
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
$SDK_Variations{'ALL'}{'kyra'} = "$DefaultTopMacros
@@ -223,10 +224,10 @@ if (1) # all regular combo's
MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
//MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
- MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+ MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
# below here you could specify weird & experimental combinations, non-ready engines
@@ -234,8 +235,7 @@ if (1) # all regular combo's
$SDK_Variations{'ALL'}{'saga_mini'} = "
//MACRO USE_ZLIB // LIB:zlib.lib
//MACRO USE_MAD // LIB:libmad.lib
- //MACRO USE_TREMOR // LIB:libtremor.lib
-
+ //MACRO USE_TREMOR // LIB:libtremor.lib
MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
MACRO DISABLE_SKY // LIB:scummvm_sky.lib
@@ -243,31 +243,30 @@ if (1) # all regular combo's
MACRO DISABLE_GOB // LIB:scummvm_gob.lib
//MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
- MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+ MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
$DefaultBottomMacros";
- $SDK_Variations{'ALL'}{'scumm_no78he'} = "
- MACRO USE_ZLIB // LIB:zlib.lib
- MACRO USE_MAD // LIB:libmad.lib
- //MACRO USE_TREMOR // LIB:libtremor.lib
- MACRO DISABLE_SCUMM_7_8
- MACRO DISABLE_SCUMM_HE
-
- //MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
- MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
- MACRO DISABLE_SKY // LIB:scummvm_sky.lib
- MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
- MACRO DISABLE_GOB // LIB:scummvm_gob.lib
- MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
- MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
- MACRO DISABLE_LURE // LIB:scummvm_lure.lib
- MACRO DISABLE_CINE // LIB:scummvm_cine.lib
- $DefaultBottomMacros";
+# $SDK_Variations{'ALL'}{'scumm_no78he'} = "
+# MACRO USE_ZLIB // LIB:zlib.lib
+# MACRO USE_MAD // LIB:libmad.lib
+# //MACRO USE_TREMOR // LIB:libtremor.lib
+# MACRO DISABLE_SCUMM_7_8
+# MACRO DISABLE_SCUMM_HE
+# //MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
+# MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
+# MACRO DISABLE_SKY // LIB:scummvm_sky.lib
+# MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
+# MACRO DISABLE_GOB // LIB:scummvm_gob.lib
+# MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
+# MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
+# MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+# MACRO DISABLE_LURE // LIB:scummvm_lure.lib
+# MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+# MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
+# $DefaultBottomMacros";
# $SDK_Variations{'ALL'}{'all_vorbis'} = "
# MACRO USE_ZLIB // LIB:zlib.lib
@@ -290,15 +289,12 @@ if (1) # all regular combo's
MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
- MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
-
- MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
- MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
+ MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
//MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_agi.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
- ";
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
+ $DefaultBottomMacros";
# empty $SDK_Variations{''} string instead of 'ALL' = package disabled
$SDK_Variations{'ALL'}{'test_cine'} = "$DefaultTopMacros
@@ -308,52 +304,44 @@ if (1) # all regular combo's
MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
- MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
-
- MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
- MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
+ MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
//MACRO DISABLE_CINE // LIB:scummvm_cine.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
-
- ";
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
+ $DefaultBottomMacros";
$SDK_Variations{'ALL'}{'test_agi'} = "$DefaultTopMacros
MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
- MACRO DISABLE_SKY // LIB:scummvm_sky.lib
+ MACRO DISABLE_SKY // LIB:scummvm_sky.lib
MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
- MACRO DISABLE_GOB // LIB:scummvm_gob.lib
+ MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
- MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
-
- MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
- MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
+ MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
//MACRO DISABLE_AGI // LIB:scummvm_agi.lib
- MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
-
- ";
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
+ $DefaultBottomMacros";
$SDK_Variations{'ALL'}{'test_touche'} = "$DefaultTopMacros
MACRO DISABLE_SCUMM // LIB:scummvm_scumm.lib
MACRO DISABLE_AGOS // LIB:scummvm_agos.lib
- MACRO DISABLE_SKY // LIB:scummvm_sky.lib
+ MACRO DISABLE_SKY // LIB:scummvm_sky.lib
MACRO DISABLE_QUEEN // LIB:scummvm_queen.lib
- MACRO DISABLE_GOB // LIB:scummvm_gob.lib
+ MACRO DISABLE_GOB // LIB:scummvm_gob.lib
MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
- MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
-
- MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
- MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
+ MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
MACRO DISABLE_LURE // LIB:scummvm_lure.lib
MACRO DISABLE_CINE // LIB:scummvm_cine.lib
- MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_AGI // LIB:scummvm_agi.lib
+ MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
//MACRO DISABLE_TOUCHE // LIB:scummvm_touche.lib
-
+ MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
+ MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
+ MACRO DISABLE_PARALLACTION // LIB:scummvm_parallaction.lib
";
}
@@ -368,6 +356,9 @@ if (1) # all regular combo's
# MACRO DISABLE_GOB // LIB:scummvm_gob.lib
# MACRO DISABLE_SAGA // LIB:scummvm_saga.lib
# MACRO DISABLE_KYRA // LIB:scummvm_kyra.lib
+# MACRO DISABLE_PARALLACTION // LIB:scummvm_parallaction.lib
+# MACRO DISABLE_CINE // LIB:scummvm_cine.lib
+# MACRO DISABLE_CRUISE // LIB:scummvm_cruise.lib
# //MACRO DISABLE_SWORD1 // LIB:scummvm_sword1.lib
# //MACRO DISABLE_SWORD2 // LIB:scummvm_sword2.lib
# ";